<div class="block" id="sidebar-globaltoc">
  <h3 class="subtitle">{{ _('Table of Contents') }}</h3>
  <aside class="menu">
    {{ toctree(includehidden=theme_globaltoc_includehidden, collapse=theme_globaltoc_collapse, maxdepth=theme_globaltoc_maxdepth)|set_menu_list }}
  </aside>
</div>
